current_core library
Core library for the Flutter and Jaspr Current State Management Packages
Classes
- BusyStatusChanged
- Event that is added to the state stream when the busy status of the view model changes.
- CurrentBoolProperty
- An CurrentProperty with similar characteristics as a an ordinary dart bool object
-
CurrentCloneable<
T> - CurrentDateTimeProperty
- An CurrentProperty with similar characteristics as a an ordinary dart DateTime object
- CurrentDoubleProperty
- An CurrentProperty with similar characteristics of dart double objects
- CurrentIntProperty
- An CurrentProperty with similar characteristics of dart int objects
-
CurrentListProperty<
T> - An CurrentProperty with similar characteristics as a dart List<T>
-
CurrentMapProperty<
K, V> - An CurrentProperty with similar characteristics as a dart Map<K, V>
- CurrentNullableBoolProperty
- An CurrentProperty with similar characteristics as a an ordinary dart bool object.
- CurrentNullableDateTimeProperty
- An CurrentProperty with similar characteristics as a an ordinary dart bool object.
- CurrentNullableDoubleProperty
- An CurrentProperty with similar characteristics of dart double objects
- CurrentNullableIntProperty
- An CurrentProperty with similar characteristics of dart int objects
- CurrentNullableStringProperty
- An CurrentProperty with similar characteristics as a dart String object
-
CurrentProperty<
T> - Contains any object that will notify any listeners when its value is changed.
-
CurrentStateChanged<
T> - The event that is added to the State stream.
- CurrentStateViewModel
- A ViewModel is an abstraction of the view it is bound to and represents the current state of the data in your model.
- CurrentStringProperty
- An CurrentProperty with similar characteristics as a dart String object
-
CurrentValue<
T> - Base class for CurrentProperty
- CurrentViewModelBinding
- Contract for helper objects that need to attach themselves to a CurrentStateViewModel after all CurrentProperty values have been initialized.
-
ErrorEvent<
T> - The event that is added to the Error stream.
Extensions
Functions
-
createNullProperty<
T> ({String? propertyName}) → CurrentProperty< T?> - Short hand helper function for initializing an CurrentProperty with a null value.
-
createProperty<
T> (T value, {String? propertyName}) → CurrentProperty< T> - Short hand helper function for initializing an CurrentProperty.
Exceptions / Errors
- CurrentException
- Base class for any Current specific exception
- CurrentIntPropertyInvalidArithmaticException
- Thrown when a CurrentIntProperty arithmetic function cannot convert its numeric result into the explicitly requested generic type.
- CurrentPropertyException
- CurrentPropertyNullValueException
- Thrown when an not-null-safe action is performed on a Nullable Current Property, and the underlying value was null.
- CurrentViewModelAlreadyAssignedException
- Thrown when a CurrentViewModel is assigned to a CurrentState, but that CurrentViewModel is already assigned to a different CurrentState.
- PropertyNotAssignedToCurrentViewModelException
- Thrown when an CurrentProperty value is changed and attempts to update the UI, but has not been added to the currentProps property of the associated CurrentViewModel